@@ -423,7 +423,6 @@ class EventPostProcessingRE(models.Model):
     value_re=models.CharField("Value RE",max_length=256)
 ##
 ## Event Correlation Rule
-## Correlation rules are the PyKE statements
 ##
 class EventCorrelationRule(models.Model):
     class Meta:
@@ -431,22 +430,57 @@ class EventCorrelationRule(models.Model):
         verbose_name_plural="Event Correlation Rules"
         ordering=["name"]
     name=models.CharField("Name",max_length=64,unique=True)
-    rule=models.TextField("Rule")
     description=models.TextField("Description",null=True,blank=True)
     is_builtin=models.BooleanField("Is Builtin",default=False)
+    rule_type=models.CharField("Rule Type",max_length=32,choices=[("Pair","Pair")])
+    action=models.CharField("Action",max_length=1,choices=[("C","Close"),("D","Drop"),("P","Root (parent)"),("c","Root (child)")])
+    same_object=models.BooleanField("Same Object",default=True)
+    window=models.IntegerField("Window (sec)",default=0)
+
     def __unicode__(self):
         return self.name
-    def _pyke_id(self):
-        return rx_py_id.sub(self.name,"_")
-    pyke_id=property(_pyke_id)
-    def _pyke_code(self):
-        s=[]
-        if self.description:
-            s+=["##"]+["## %s"%l for l in self.description.split("\n")]+["##"]
-        s+=[self.pyke_id]
-        s+=["    %s"%l for l in self.rule.split("\n")]+[""]
+        
+    def python_link(self):
+        return "<A HREF='/fm/py_event_correlation_rule/%d/'>Python</A>"%self.id
+    python_link.short_description="Python"
+    python_link.allow_tags=True
+    ##
+    ## Python representation of data structure
+    ##
+    def _python_code(self):
+        s=["from noc.fm.rules.correlation import *"]
+        s+=["##","## %s"%self.name,"##"]
+        s+=["class %s_Rule(CorrelationRule):"%rx_py_id.sub("_",self.name)]
+        s+=["    name=\"%s\""%py_q(self.name)]
+        s+=["    description=\"%s\""%py_q(self.description)]
+        s+=["    rule_type=\"%s\""%py_q(self.rule_type)]
+        s+=["    action=%s"%{"C":"CLOSE_EVENT"}[self.action]]
+        s+=["    same_object=%s"%self.same_object]
+        s+=["    window=%s"%self.window]
+        s+=["    classes=[%s]"%(",".join([rx_py_id.sub("",x.event_class.name) for x in self.eventcorrelationmatchedclass_set.all()]))]
+        s+=["    vars=[%s]"%(",".join(["\"%s\""%x.var for x in self.eventcorrelationmatchedvar_set.all()]))]
         return "\n".join(s)
-    pyke_code=property(_pyke_code)
+    python_code=property(_python_code)
+##
+## Matched class list for correlation rule
+##
+class EventCorrelationMatchedClass(models.Model):
+    class Meta:
+        verbose_name="Event Correlation Rule Matched Class"
+        verbose_name="Event Correlation Rule Matched Classes"
+        unique_together=[("rule","event_class")]
+    rule=models.ForeignKey(EventCorrelationRule,verbose_name="Rule")
+    event_class=models.ForeignKey(EventClass,verbose_name="Event Class")
+##
+## Matched var list for correlation rule
+##
+class EventCorrelationMatchedVar(models.Model):
+    class Meta:
+        verbose_name="Event Correlation Rule Matched Var"
+        verbose_name="Event Correlation Rule Matched Vars"
+        unique_together=[("rule","var")]
+    rule=models.ForeignKey(EventCorrelationRule,verbose_name="Rule")
+    var=models.CharField("Variable Name",max_length=256)
 ##
 ## Event itself
 ##
@@ -560,6 +594,17 @@ class EventLog(models.Model):
     to_status=models.CharField("To Status",max_length=1,choices=EVENT_STATUS_CHOICES)
     message=models.TextField("Message")
 ##
+##
+##
+class EventArchivationRule(models.Model):
+    class Meta:
+        verbose_name="Event Archivation Rule"
+        verbose_name_plural="Event Archivation Rules"
+    event_class=models.ForeignKey(EventClass,verbose_name="Event Class",unique=True)
+    ttl=models.IntegerField("Time To Live")
+    ttl_measure=models.CharField("Measure",choices=[("s","Seconds"),("m","Minutes"),("h","Hours"),("d","Days")],default="h",max_length=1)
+    action=models.CharField("Action",choices=[("D","Drop")],default="D",max_length=1)
+##
 ## Application Menu
 ##
 class AppMenu(Menu):
@@ -567,6 +612,7 @@ class AppMenu(Menu):
     title="Fault Management"
     items=[
         ("Events", "/fm/", "fm.change_event"),
+        ("Active Problems", "/fm/active_problems_summary/", "fm.change_event"),
         ("Setup", [
             ("MIBs",                "/admin/fm/mib/",                     "fm.change_mib"),
             ("MIB Data",            "/admin/fm/mibdata/",                 "fm.change_mibdata"),
@@ -576,5 +622,6 @@ class AppMenu(Menu):
             ("Classification Rules","/admin/fm/eventclassificationrule/", "fm.change_eventclassificationrule"),
             ("Post-Processing Rules", "/admin/fm/eventpostprocessingrule/", "fm.change_eventpostprocessingrule"),
             ("Correlation Rules",   "/admin/fm/eventcorrelationrule/",    "fm.change_eventcorrelationrule"),
+            ("Archivation Rules",   "/admin/fm/eventarchivationrule/",    "fm.change_eventarchivationrule"),
         ])
     ]
