@@ -124,7 +124,7 @@ class AssignAddressForm(forms.Form):
 
 rx_url_cidr=re.compile(r"^.*/(\d+\.\d+\.\d+\.\d+/\d+)/$")
 
-def assign_address(request,vrf_id,ip=None):
+def assign_address(request,vrf_id,ip=None,new_ip=None):
     vrf=get_object_or_404(VRF,id=int(vrf_id))
     if ip:
         assert is_ipv4(ip)
@@ -136,6 +136,10 @@ def assign_address(request,vrf_id,ip=None):
             "tt"          : address.tt,
         }
         p="/"+ip
+    elif new_ip:
+        assert is_ipv4(new_ip)
+        initial={"ip":new_ip}
+        p=""
     else:
         initial={}
         p=""
@@ -213,14 +217,13 @@ def download_ips(request,vrf_id,prefix):
         else:
             return ""
     assert is_cidr(prefix)
-    vrf_id=int(vrf_id)
-    vrf=get_object_or_404(VRF,id=vrf_id)
+    vrf=get_object_or_404(VRF,id=int(vrf_id))
     if not IPv4BlockAccess.check_write_access(request.user,vrf,prefix):
         return HttpResponseForbidden("Permission denied")
     block=get_object_or_404(IPv4Block,vrf=vrf,prefix=prefix)
     out=cStringIO.StringIO()
     writer=csv.writer(out)
-    for a in block.addresses:
+    for a in block.nested_addresses:
         writer.writerow([a.ip,a.fqdn,to_utf8(a.description),a.tt])
     return HttpResponse(out.getvalue(),mimetype="text/csv")
 ##
