@@ -10,6 +10,12 @@
 from django.contrib import admin
 from noc.main.models import *
 
+##
+##
+##
+class AuditTrailAdmin(admin.ModelAdmin):
+    list_display=["user","timestamp","model","db_table","operation","subject"]
+    list_filter=["user"]    
 ##
 ## Admin for Language
 ##
@@ -38,6 +44,7 @@ class RefBookAdmin(admin.ModelAdmin):
 ##
 ## Register administrative interfaces
 ##
+admin.site.register(AuditTrail, AuditTrailAdmin)
 admin.site.register(Language, LanguageAdmin)
 admin.site.register(MIMEType, MIMETypeAdmin)
 admin.site.register(RefBook, RefBookAdmin)
