@@ -23,8 +23,6 @@ class Profile(noc.sa.profiles.Profile):
     requires_netmask_conversion=True
     convert_mac=noc.sa.profiles.Profile.convert_mac_to_cisco
     config_volatile=["^ntp clock-period .*?^"]
-    oid_trap_config_changed="1.3.6.1.4.1.9.9.43.2"
-    syslog_config_changed="%SYS-5-CONFIG_I: Configured from"
     
     def generate_prefix_list(self,name,pl,strict=True):
         p="ip prefix-list %s permit %%s"%name
